data "keycloak_realm" "realm" {
  realm = var.realm
}

resource "keycloak_openid_client" "client" {
  realm_id  = data.keycloak_realm.realm.id
  client_id = var.client_id
  client_secret = var.client_secret

  name        = var.client_name
  description = var.description

  enabled                   = var.enabled
  access_type               = var.access_type
  client_authenticator_type = var.client_authenticator_type

  root_url               = var.root_url
  base_url               = var.base_url
  admin_url              = var.admin_url
  backchannel_logout_url = var.backchannel_logout_url

  valid_redirect_uris = var.valid_redirect_uris
  web_origins         = var.web_origins

  login_theme = var.login_theme

  standard_flow_enabled        = true
  implicit_flow_enabled        = false
  direct_access_grants_enabled = true
  service_accounts_enabled     = false
  frontchannel_logout_enabled  = var.frontchannel_logout_enabled
  oauth2_device_authorization_grant_enabled = var.device_authorization_grant_enabled

}

resource "keycloak_role" "restricted-access" {
  realm_id    = data.keycloak_realm.realm.id
  client_id   = keycloak_openid_client.client.id
  name        = "restricted-access"
  description = "Restricts access to the client"
}

resource "keycloak_role" "admin-role" {
  realm_id    = data.keycloak_realm.realm.id
  client_id   = keycloak_openid_client.client.id
  name        = "${var.admin_role_name != null ? "${var.admin_role_name}" : "${var.client_name}-admin"}"
  description = "Client Admin permissions"
}

resource "keycloak_group" "access_group" {
  realm_id = data.keycloak_realm.realm.id
  name     = var.client_name
}

resource "keycloak_group" "admin_group" {
  realm_id = data.keycloak_realm.realm.id
  parent_id = keycloak_group.access_group.id
  name     = "${var.client_name}-admin"
}

resource "keycloak_group_roles" "access_group_roles" {
  realm_id = data.keycloak_realm.realm.id
  group_id = keycloak_group.access_group.id
  role_ids = [
    keycloak_role.restricted-access.id
  ]
}

resource "keycloak_group_roles" "admin_group_roles" {
  realm_id = data.keycloak_realm.realm.id
  group_id = keycloak_group.admin_group.id
  role_ids = [
    keycloak_role.admin-role.id
  ]
}
